/******************************************************************
*****************  				KENYA 			  *****************
*****************  		Decision making paper	  *****************
			  
*** PURPOSE: This do-file prepares dataset for the decision making paper 

Date: January, 2025
Stata version: 18
******************************************************************//* 												   
clear all
set more off
set dp period
set seed 1001

*** Work directory
   if "`c(username)'"=="marti" {
		global main   = "C:\Users\marti\Dropbox\Trabajos-Concursos-etc\Oxford-WEAI\Kenya Water Survey round 2\Data and dofiles\Replication package"
	}
else if "`c(username)'"=="mquerejeta" {
		global main   = "C:\Users\mquerejeta\Dropbox\Trabajos-Concursos-etc\Oxford-WEAI\Kenya Water Survey round 2\Data and dofiles\Replication package"
	}
else if "`c(username)'"=="hille" {
		global main   = "C:\Users\hille\Dropbox\Oxford-WEAI\Kenya Water Survey round 2\Data and dofiles\Replication package"
	}

else if "`c(username)'"=="Marya Hillesland" {
		global main   = "C:\Users\Marya Hillesland\OneDrive\Desktop\Replication_package" 
	}	
*/	
* Drop households with discrepancies in the relationships, ages, and/or gender, or with missing information on water
program dropvars
drop if b01==567 | b01==589 | b01==1115 | b01==1190| b01==1393 | b01==3271 | b01==3327 | b01==3411 | b01==3420 | b01==4868 |b01==4774  | b01==4784| b01==4822 | b01==5611 | b01==5768 | b01==6157 | b01==7120
end

******************************************************************
*** 	Individual characteristics
*******************************************************************
use "$main\Raw data\Individual\individual level.dta", clear 

g mono_married=(y_status==1)
g pol_married=(y_status==2)
g never_married=(y_status==6)
g wi_div_sep=(y_status==4|y_status==5)

g educ_attending=(ed_school==1)
g educ_illiterate=(ed_grade>=0  & ed_grade<=1)
g educ_primary  =(ed_grade>=2  & ed_grade<=9)
g educ_sec_tert=(ed_grade>=10 & ed_grade<=18)

g Ganze=(a01==1)
g Kaloleni=(a01==2)
g Magarini=(a01==3)

duplicates tag b01 y_id, g(dup)
drop if dup!=0
keep b01 y_id y_age mono_married pol_married never_married wi_div_sep educ_* Ganze Kaloleni Magarini 
saveold "$main\Indiv_charac.dta", replace

use "$main\Raw data\Household\household roster.dta", clear
*rename parent_key hh_key
rename hh_relation ind_relationship
rename member_id hh_id
gen y_id=1
duplicates drop
duplicates report b01 y_id hh_id
duplicates tag b01 y_id hh_id, generate(tag)
dropvars // 304 observations deleted
drop if b01==3197 |  b01==7588 | b01==7516 | b01==1089 | b01==1099 | b01==3781 // 132 observations deleted
egen sex=max(hh_sex), by(b01 hh_id)
egen age=max(hh_age), by(b01 hh_id)
drop hh_sex hh_age
rename (sex age) (hh_sex hh_age)
drop parent_key tag hh_education hh_school 
duplicates drop // 1,506
drop if b01==2307 & hh_id==1 & hh_spouse==2
drop if b01==2418 & hh_id==4 & hh_marital==6
drop if b01==3855 & hh_id==1 & hh_spouse==2
merge 1:m b01 y_id hh_id using "$main\Raw data\Individual\Relationships to others in the household.dta"
drop _m
sort b01 y_id
numlabel, add mask("#. ")
tab ind_relationship
* Sex of all individuals
egen sex=max(hh_sex), by(b01 hh_id)
preserve
egen age=max(hh_age), by(b01 hh_id)
keep b01 hh_id sex ind_relationship y_id y_sex age hh_marital hh_spouse
rename sex hh_sex
rename age hh_age
replace ind_relationship=1 if hh_id==y_id
drop if ind_rel==. // 101 missing
saveold "$main\all_rel.dta", replace
restore
* Do they live with their parents
egen hh_parents=max(ind_relationship==6|ind_relationship==14),by(b01 y_id)
* Do they live with their in-laws
egen hh_inlaws=max(ind_relationship==7),by(b01 y_id)

keep b01 y_id hh_parents hh_inlaws 
duplicates drop
saveold "$main\ind_rel.dta", replace

*******************************************************************
*** 	Household characteristics
*******************************************************************
*** Household type
use "$main\all_rel.dta", clear
gen child = (hh_age <18)
gen adult = (hh_age >=18)

* observations where child married and spouse in household
replace child = 0 if (hh_marital<3 & hh_spouse==1)
replace adult = 1 if (hh_marital<3 & hh_spouse==1)

* household has cowives, parent in law, couple(s), extended family
egen hh_cowives = max(ind_relationship==19), by(b01)
egen hh_parent_inlaws = max((ind_relationship==7) | (ind_relationship==4)),by(b01)
egen hh_sibling_inlaws = max((ind_relationship==13)),by(b01)
egen hh_couple = max(ind_relationship==2),by(b01)
egen hh_couple_num = total(ind_relationship==2),by(b01)
egen hh_grandparents = max(ind_relationship==5 | ind_relationship==14),by(b01)
egen hh_extended = max((ind_relationship==5) | (ind_relationship==7) |(ind_relationship==11) | (ind_relationship==12) | (ind_relationship==13) | (ind_relationship==21) | (ind_relationship==14) | (ind_relationship==15) | (ind_relationship==18)), by(b01)
egen hh_other_relative = max(ind_relationship==18),by(b01)

* Manually fix households
	replace y_sex = 2 if hh_id==2 & b01==590 
	replace y_sex = 1 if hh_id==2 & b01==6563 
	replace y_sex = 1 if hh_id==2 & b01==3420
	replace ind_relationship=3 if hh_id==3 & b01==590 
	replace ind_relationship=1 if y_id==hh_id

keep if y_id==1
egen n_adults = total(adult==1), by(b01)
egen n_women = total(adult==1 & hh_sex==2), by(b01)
egen n_men = total(adult==1 & hh_sex==1), by(b01)
egen n_total = total(y_id), by(b01)

* self, partner, kids, parents
gen tag = (ind_relationship<=3 | ind_relationship==10 | ind_relationship==9)
egen members = total(tag==1), by(b01) 

* keep one per household
keep if hh_id==1
* household types
gen household_type = .
* couple only
tab hh_couple n_adults
replace household_type = 3 if hh_couple==1 & n_women==1 & n_men==1
* extended 
replace household_type = 5 if (hh_extended==1 | hh_parent_inlaws==1 | hh_sibling_inlaws==1 | hh_other_relative==1 | hh_grandparents==1 & hh_couple_num)
* co-wives
replace household_type = 6 if hh_cowives>0
* one adult female  
replace household_type = 1 if hh_couple==0 & n_women==1 & n_adults==1 & household_type==.
* one adult male
replace household_type = 2 if hh_couple==0 & n_men==1 & n_adults==1 & household_type==.
* parents with adult children 
replace household_type = 4 if members==n_total & household_type==.
* checked data above
replace household_type=4 if b01==620 | b01==362 | b01==2283 | b01==6294 | b01==3152 | b01==6227
replace household_type=5 if b01==3411
label define household 1 "Single adult woman" 2 "Single adult man"  3 "Couple" 4 "Parents with adult children" 5 "Extended family households" 6 "Households with co-wives"
label values household_type household
keep b01 household_type 
duplicates drop
duplicates report b01
saveold "$main\htype.dta", replace

use "$main\Raw data\Household\household roster.dta", clear
rename member_id y_id
merge m:1 b01 using "$main\htype.dta", keepusing(household_type)
drop if _m==2
drop _m
g ht_single=(household_type==1|household_type==2)
g ht_couple=(household_type==3)
g ht_parent_adult=(household_type==4)
g ht_extended=(household_type==5)
g ht_cowives=(household_type==6)

keep b01 household_type ht_* 
duplicates drop
duplicates report b01

dropvars // 17 observations deleted
saveold "$main\HH_charac.dta", replace

*******************************************************************
*** 	PREFERENCES - SOURCE FOR DRINKING WATER
*******************************************************************
* HOUSEHOLD: WATER SOURCES USED FOR DRINKING
use "$main\Raw data\Household\Water sources used and not used.dta", clear
ta ws_use_1
keep if ws_use_1==1 // Only sources used for drinking
keep b01 waterdetails_id ws_freq ws_use_1
saveold "$main\WS_USED.dta", replace

* INDIVIDUAL: PREFERED WATER SOURCES FOR DRINKING
use "$main\Raw data\Individual\individual level.dta", clear
keep b01 y_id  water_best1 water_best2 water_best3 
dropvars // 60 observations deleted
duplicates drop
reshape long water_best, i(b01 y_id) j(order)
label define order 1"First option" 2"Second option" 3"Third option", replace
label values order order
rename water_best waterdetails_id
merge m:m b01 waterdetails_id using "$main\WS_USED.dta"
drop if _m==2
g used=(_m==3)

drop if b01==1 | y_id==.
duplicates drop
duplicates report b01 y_id // 3 each

egen any_3=max(used), by(b01 y_id)
forvalues var=1/3 {
g best`var'_used_=(order==`var' & used==1)
egen best`var'_used=max(best`var'_used_), by(b01 y_id)
drop best`var'_used_
}
keep b01 y_id any_3 best*
duplicates drop
duplicates report b01 y_id // No dup - OK
saveold "$main\WS_USED.dta", replace

*******************************************************************
*** 	Module on DM - Part 1
*******************************************************************

use "$main\Raw data\Individual\Module 5 BN decision making part 1.dta", clear 
merge m:1 b01 using "$main\Raw data\samplingweights_round2.dta", keepusing(sampling_weight) 
drop if _m==2 // 270 using only

g female=(y_s==2)

* 3 categories of decision makers: Sole, Joint and Non-DM
g own_dm=0
forvalues ind=1/19 {
replace own_dm=1 if bn_decision_`ind'==1 & y_id==`ind'
}
* Decisions not made in the HH
g dm_notmade_hh=(bn_decision_id==-88 | bn_decision_id==.)

g dm_categ=.
replace dm_categ=1 if own_dm==1 & bn_number==1 // Only him/herself
replace dm_categ=2 if own_dm==1 & bn_number!=1 // Joint DM
replace dm_categ=3 if own_dm==0 // Non-DM
replace dm_categ=4 if dm_notmade_hh==1 // Decision not made in HH
label define dm_categ 1"Sole DM" 2"Joint DM" 3"Non-DM" 4"Not made in HH", replace
label values dm_categ dm_categ

* Percentage of participation in DM
destring bn_authority_total, replace
g perc_authority_=.
forvalues ind=1/19 {
replace perc_authority_=bn_authority/bn_authority_total if bn_decision_id==`ind' & y_id==`ind'
}
ta perc_authority if dm_categ!=2,m // All missing
replace perc_authority=1 if dm_categ==1 // Replace Sole DM by 100%
replace perc_authority=0 if (dm_categ==3|dm_categ==4) // Replace Non-DM by 0%
egen perc_authority=max(perc_authority_), by(b01 y_id female y_age bn_activity_id)
*egen perc_authority2=min(perc_authority_), by(b01 y_id female y_age bn_activity_id)

g numb_dm=bn_number
replace numb_dm=5 if bn_number==4 & bn_dec_number==1
replace numb_dm=. if dm_categ==4 // DM not made in HH
label define numb_dm 5"5+", replace
label values numb_dm numb_dm

keep sampling_weight b01 y_id y_sex female y_age bn_activity_id numb_dm dm_categ perc_authority dm_notmade_hh
duplicates drop // Cause each individual-activity appears as times as DMakers declared for that activity
duplicates tag b01 y_id, g(a)
drop if a>6 // Should be 6 or less as there are 7 activities - 2% of sample dropped
drop a
rename bn_activity_id activity_id
saveold "$main\DM.dta", replace

*** Who are the other DM's
use "$main\Raw data\Household\household roster.dta", replace
keep b01 member_id hh_relation
rename member_id hh_id
g y_id=1
saveold "$main\hh_relation.dta", replace

*** Who is making decisions with DM's
use "$main\Raw data\Individual\Module 5 BN decision making part 1.dta", clear 
rename bn_activity_id activity_id
destring bn_authority_total, replace
g 		perc_authority=bn_authority/bn_authority_total 
replace perc_authority=0 if (bn_decision_id==-88 | bn_decision_id==.)
replace perc_authority=1 if (bn_number==1)
count if perc_authority==. // No cases
keep b01 y_id activity_id bn_decision_id bn_number perc_authority 
duplicates drop //19
rename bn_decision_id hh_id
duplicates report b01 y_id activity_id hh_id // 0 ok
merge m:m b01 y_id hh_id using "$main\all_rel.dta"
keep if _m==3
drop _m
g self=(y_id==hh_id) 
egen max_self=max(self), by(b01 y_id activity_id)
ta max_self, m // 30% non-DMs
gen adult = (hh_age >=18) if hh_age!=.
numlabel, add mask("#. ")
tab ind_relationship, m // No miss
ta hh_sex,m // 369 missing
ta adult,m // 369 missing

g wife_cowife=((ind_relation==2|ind_relation==19)&hh_sex==2)
g wife=(ind_relation==2&hh_sex==2)
g cowife=(ind_relation==19&hh_sex==2)
g husband    =(ind_relation==2&hh_sex==1)
g dau=((ind_relation==3|ind_relation==9|ind_relation==10)&hh_sex==2)
g son=((ind_relation==3|ind_relation==9|ind_relation==10)&hh_sex==1)
g dauinlaw=(ind_relation==4&hh_sex==2)
g soninlaw=(ind_relation==4&hh_sex==1)
g dau_dauinlaw=((ind_relation==3|ind_relation==10|ind_relation==4)&hh_sex==2)
g son_soninlaw=((ind_relation==3|ind_relation==10|ind_relation==4)&hh_sex==1)
g granddau=(ind_relation==5&hh_sex==2)
g grandson=(ind_relation==5&hh_sex==1)
g mother_stepm=((ind_relation==6|ind_relation==22)&hh_sex==2)
g father_stepf=((ind_relation==6|ind_relation==22)&hh_sex==1)
g mother_inlaw=(ind_relation==7&hh_sex==2)
g father_inlaw=(ind_relation==7&hh_sex==1)
g sis=(ind_relation==8&hh_sex==2)
g bro=(ind_relation==8&hh_sex==1)
g sisinlaw=(ind_relation==13&hh_sex==2)
g broinlaw=(ind_relation==13&hh_sex==1)
g sis_sisinlaw=((ind_relation==8|ind_relation==13)&hh_sex==2)
g bro_broinlaw=((ind_relation==8|ind_relation==13)&hh_sex==1)
g niece=(ind_relation==11&hh_sex==2)
g nephew=(ind_relation==11&hh_sex==1)
g aunt=(ind_relation==12&hh_sex==2)
g uncle=(ind_relation==12&hh_sex==1)
g grandmother=(ind_relation==14&hh_sex==2)
g grandfather=(ind_relation==14&hh_sex==1)
cap drop check
egen check=rowtotal(self wife_cowife husband mother_stepm father_stepf mother_inlaw father_inlaw dau_ son_ sis_sisinlaw bro_broinlaw) 
ta check // 97%
tab ind_relationship hh_sex if check==0
g other_fem_adult=(adult==1&hh_sex==2&check==0)
g other_men_adult=(adult==1&hh_sex==1&check==0)
g other_fem_child=(adult==0&hh_sex==2&check==0)
g other_men_child=(adult==0&hh_sex==1&check==0)
g other_men=sis_sisinlaw+other_men_adult+other_men_child
g other_fem=bro_broinlaw+other_fem_adult+other_fem_child

cap drop check
egen check=rowtotal(self wife_cowife husband mother_stepm father_stepf mother_inlaw father_inlaw dau_ son_ sis_sisinlaw bro_broinlaw other_fem_adult other_men_adult other_fem_child other_men_child) 
ta check // 99%

global hhrel="wife_cowife wife cowife husband dau son dauinlaw soninlaw dau_dauinlaw son_soninlaw granddau grandson mother_stepm father_stepf mother_inlaw father_inlaw sis bro sisinlaw broinlaw sis_sisinlaw bro_broinlaw niece nephew aunt uncle grandmother grandfather other_fem_adult other_men_adult other_fem_child other_men_child other_men other_fem"
*preserve
egen max_perc_authority=max(perc_authority), by(b01 y_id activity_id)
g max_authority=(max_perc_authority==perc_authority)
ta max_authority // 80%
egen n_max_authority=sum(max_authority), by(b01 y_id activity_id)
ta n_max_authority // 70% only one

keep if max_perc_authority==perc_authority
drop if perc_authority==0 // 0
foreach var of varlist self $hhrel {
egen `var'_=sum(`var'), by(b01 y_id activity_id)
drop `var'
rename `var'_ `var'
}
keep b01 y_id activity_id perc_authority n_max_authority self $hhrel
duplicates drop
duplicates report b01 y_id activity_id // There are some with more that 1 highest %
sort b01 y_id activity_id perc_authority 
saveold "$main\DM_who_max_authority.dta", replace

*********************************************************************
*** 	INVOLVEMENT
*********************************************************************
use "$main\Raw data\Individual\BA notinvolved consequences.dta", clear
forval num = 1/7 {
cap drop ba_notinvolved_con2_`num'
g ba_notinvolved_con2_`num'=(ba_notinvolved_con21==`num'|ba_notinvolved_con22==`num'|ba_notinvolved_con23==`num'|ba_notinvolved_con24==`num') if ba_notinvolved_con1==1
}
save "$main\BA notinvolved.dta", replace

use "$main\Raw data\Individual\Noninvolvement and Backlash.dta", clear
keep b01 y_id y_sex y_age ba_activity_id ni_desire ni_reasons_*
recode ni_desire (2=0)
rename ba_activity_id ba_inv_activity_id
merge m:m b01 y_id y_sex y_age ba_inv_activity_id using "$main\Raw data\Individual\BA involved consequences.dta",keepusing(ba_involved_con1 ba_involved_con2* ba_inv_pref ba_inv_freq)
drop if _m==2
drop _m
forval num = 1/8 {
cap drop ba_involved_con2_`num'
g ba_involved_con2_`num'=(ba_involved_con21==`num'|ba_involved_con22==`num'|ba_involved_con23==`num'|ba_involved_con24==`num'|ba_involved_con25==`num') if ba_involved_con1==1
}
rename ba_inv_activity_id ba_activity_notinv_id
merge m:m b01 y_id y_sex y_age ba_activity_notinv_id using "$main\BA notinvolved.dta",keepusing(ba_notinvolved_con1 ba_notinvolved_con2_* ba_notinvolved)
drop if _m==2
drop _m
duplicates tag b01 y_id, g(a)
ta a 
drop if a>6 // HH 567 and 4868
drop a
rename ba_activity_notinv_id activity_id
recode ba_notinvolved_con1 ba_notinvolved ba_involved_con1 ba_inv_pref ba_inv_freq (2=0)
drop  ni_reasons_oth ba_involved_con1 ba_involved_con2 ba_involved_con21 ba_involved_con22 ba_involved_con23 ba_involved_con24 ba_involved_con25 ba_involved_con2_oth ba_inv_pref ba_inv_freq
save "$main\Involvement.dta", replace

********************************************************************
*** 	CONFLICT
********************************************************************
use "$main\Raw data\Individual\Module 05A DM decision making part 2.dta", clear  
keep b01 y_id y_sex y_age dm_activity dm_*
rename dm_activity activity_id
recode dm_pref dm_tactic_most (2=0)
duplicates tag b01 y_id, g(a)
ta a 
drop if a>6 // HH 567 and 4868
drop a
save "$main\Conflict.dta", replace

*********************************************************************
*** 	PERSUATION
*********************************************************************
* THESE QUESTIONS ARE ANSWERED if (DM_control>1 OR DM_newsolutions>1) 
use "$main\Raw data\Individual\persuasion.dta", clear
keep b01 y_id y_sex dm_ps_id ps_1 ps_2_* ps_3 ps_4
drop ps_2_88
rename dm_ps_id activity_id
recode ps_1 ps_3 (2=0)
duplicates report b01 y_id activity_id 
save "$main\Persuation.dta", replace

*********************************************************************
*** 	FINAL DATASET
*********************************************************************
use "$main\HH_charac.dta", clear
duplicates report b01 // 624 households
merge 1:m b01 using "$main\Indiv_charac.dta"
keep if _m==3
drop _m
merge 1:1 b01 y_id using "$main\ind_rel.dta"
keep if _m==3
drop _m
merge 1:m b01 y_id using "$main\DM.dta"
keep if _m==3
drop _m
merge 1:1 b01 y_id activity_id using "$main\Involvement.dta"
drop if _m==2
drop _m
merge 1:1 b01 y_id activity_id using "$main\Conflict.dta"
drop if _m==2
drop _m
merge 1:1 b01 y_id activity_id using "$main\Persuation.dta"
drop if _m==2
drop _m
merge m:1 b01 y_id using "$main\WS_USED.dta"
drop if _m==2
drop _m

* Type of DM
g water=(activity_id<=3)
g expenditure=(activity_id==2|activity_id==4)
g health_ownincome=(activity_id==5|activity_id==7)
g individual=(activity_id==5|activity_id==6|activity_id==7)
g household=(activity_id>=1 & activity_id<=4)

*** EFFECTIVE POWER VARIABLES
gen no_desire = (ni_desire==0)
* Effective power by Proxy 
gen proxy_power = ((ni_reasons_1==1 | ni_reasons_2==1 | ni_reasons_3==1) & dm_categ==3 & no_desire==1)
replace proxy_power = 0 if ((ni_reasons_4==1 | ni_reasons_5==1 | ni_reasons_6==1 | ni_reasons_7==1) & dm_categ==3 & no_desire==1)
replace proxy_power = . if dm_notmade_hh==1

* Effective power by persuasion
gen blame = strmatch(ba_notinvolved_con2_oth, "*dispise*") | strmatch(ba_notinvolved_con2_oth, "*despise*") | strmatch(ba_notinvolved_con2_oth, "*quarrel*") | strmatch(ba_notinvolved_con2_oth, "*borrow money*") | strmatch(ba_notinvolved_con2_oth, "*not allow*") | strmatch(ba_notinvolved_con2_oth, "*ruin*") | strmatch(ba_notinvolved_con2_oth, "*blame*") | strmatch(ba_notinvolved_con2_oth, "*Blame*") | strmatch(ba_notinvolved_con2_oth, "*ignore*") | strmatch(ba_notinvolved_con2_oth, "*misunderstanding*") | strmatch(ba_notinvolved_con2_oth, "*Misunderstanding*")| strmatch(ba_notinvolved_con2_oth, "*conflict*") | strmatch(ba_notinvolved_con2_oth, "*Conflict*") | strmatch(ba_notinvolved_con2_oth, "*fear*") | strmatch(ba_notinvolved_con2_oth, "*mad*") | strmatch(ba_notinvolved_con2_oth, "*neglect*") | strmatch(ba_notinvolved_con2_oth, "*not given*") | strmatch(ba_notinvolved_con2_oth, "*not good*") | strmatch(ba_notinvolved_con2_oth, "*suffer*") | strmatch(ba_notinvolved_con2_oth, "*inlaws*")
gen no_agency = ((ni_reasons_4==1 | ni_reasons_5==1 | ni_reasons_6==1 | ni_reasons_7==1 | ba_involved_con2_1==1 | ba_involved_con2_2==1 | ba_involved_con2_3==1 | ba_involved_con2_4==1 | blame==1) & dm_categ==3 & no_desire==1)
replace no_agency = 1 if (dm_categ==3 & no_desire==0)

gen persuades = (ps_1==1 & ps_4>2) if dm_categ==3
gen voice = ((dm_tactic==2 | dm_tactic==3| dm_tactic==5) & ps_4>2) if dm_categ==3

gen persuasion_power = ((voice==1 | persuades==1) & no_agency==1)
replace persuasion_power = . if dm_notmade_hh==1

gen effective_power = (persuasion==1 | proxy_power==1)
replace effective_power = . if dm_notmade_hh==1

*** SHARES
* Share of decision making activities that the individual is not involved but has effective power
gen effpower = effective_power if dm_categ==3
bysort b01 y_id: egen effpower_count = total(effpower)
bysort b01 y_id: egen count_decision3 = total(dm_categ==3)
gen share_effective_power = effpower_count/count_decision3

* Share only on water questions (3 water questions) 
bysort b01 y_id: egen effpower_count_water = total(effpower==1 & water==1)
bysort b01 y_id: egen count_decision3_water = total(dm_categ==3 & water==1)
gen share_effective_power_water = effpower_count_water/count_decision3_water

* Share only on expenditures (water and household)
bysort b01 y_id: egen effpower_count_exp = total(effpower==1 & expenditure==1)
bysort b01 y_id: egen count_decision3_exp = total(dm_categ==3 & expenditure==1)
gen share_effective_power_exp = effpower_count_exp/count_decision3_exp

* Share only on individual decisions
bysort b01 y_id: egen effpower_count_ind = total(effpower==1 & individual==1)
bysort b01 y_id: egen count_decision3_ind = total(dm_categ==3 & individual==1)
gen share_effective_power_ind = effpower_count_ind/count_decision3_ind

* Those that are non-DM in at least one decision
g dm_categ3=(dm_categ==3)
egen cant_nondm=sum(dm_categ3), by(b01 y_id)
g nondm=cant_nondm!=0

* Those that are DM in all decisions made in the household
g all=(nondm==0)

* N decisions they are involved
egen cant_dm=total(dm_categ==1|dm_categ==2), by(b01 y_id)
egen total_dm=total(dm_categ==1|dm_categ==2|dm_categ==3), by(b01 y_id)
g share_dm=cant_dm/total_dm

* Share only on water questions (3 water questions)
bysort b01 y_id: egen dm_count_water = total((dm_categ==1|dm_categ==2) & water==1)
bysort b01 y_id: egen count_water = total(dm_categ!=4 & water==1)
gen share_dm_water = dm_count_water/count_water 

* Share only on expenditures (water and household) 
bysort b01 y_id: egen dm_count_exp = total((dm_categ==1|dm_categ==2) & expenditure==1)
bysort b01 y_id: egen count_exp = total(dm_categ!=4 & expenditure==1)
gen share_dm_exp = dm_count_exp/count_exp 

* Share only on individual decisions
bysort b01 y_id: egen dm_count_ind = total((dm_categ==1|dm_categ==2) & individual==1)
bysort b01 y_id: egen count_ind = total(dm_categ!=4 & individual==1)
gen share_dm_ind = dm_count_ind/count_ind 

* N decisions they are involved - water-related
egen cant_dm_water=total((dm_categ==1|dm_categ==2) & water==1), by(b01 y_id)
egen total_dm_water=total((dm_categ==1|dm_categ==2|dm_categ==3) & water==1), by(b01 y_id)

*** Type of household
g categ_hh=.
*Married women and men in couple households (69 men and 77 women)
replace categ_hh=1 if (mono_married==1|pol_married==1) & ht_couple==1 
*Married women and men in extended family households with wives’ in laws  (195 men and 220 women)
replace categ_hh=2 if (mono_married==1|pol_married==1) & ((female==1 & hh_inlaws==1) | (female==0 & hh_parents==1)) & ht_extended==1 
*Married women and men in extended family households without wives’ in laws or cowives 
replace categ_hh=3 if (mono_married==1|pol_married==1) & ((female==1 & hh_inlaws==0) | (female==0 & hh_parents==0)) & ht_extended==1 
*Married women and men in households with cowives (not very many of these)
replace categ_hh=4 if (mono_married==1|pol_married==1) & ht_cowives==1 
*Never married men and women who live with one or both parents (249 men and 153 women)
replace categ_hh=5 if never_married==1 & hh_parents==1
*Divorced or widowed women (196 women)
replace categ_hh=6 if wi_div_sep==1 
lab define categ_hh 1"Married in couple household with no other adults" ///
2"Married in extended family household with wife's in-laws" ///
3"Married in extended family household without wife's in-laws" ///
4"Married in household with co-wives" ///
5"Never married living with parent(s)" ///
 6"Widow/er, divorced, or separated", replace
lab values categ_hh categ_hh
ta categ_hh female if activity==1,m 

* NEW share (adding up eff power and dm) for all decisions, hh, ind, and water-related. 
g share_all = (cant_dm+effpower_count)/total_dm
* Individual decisions
bysort b01 y_id: egen allpower_count_ind = total((dm_categ==1|dm_categ==2|effpower==1) & (activity_id>=5 & activity_id<=7))
gen share_ind = dm_count_ind/count_ind
gen share_all_ind = allpower_count_ind/count_ind
* Water decisions
bysort b01 y_id: egen allpower_count_water = total((dm_categ==1|dm_categ==2|effpower==1) & water==1)
gen share_water = dm_count_water/count_water
gen share_all_water = allpower_count_water/count_water
* Expenditure decisions
bysort b01 y_id: egen allpower_count_exp = total((dm_categ==1|dm_categ==2|effpower==1) & expenditure==1)
gen share_exp = dm_count_exp/count_exp
gen share_all_exp = allpower_count_exp/count_exp

* Involvement in DM
forvalues i =1/7 {
g dm`i'_=(activity_id==`i' & (dm_categ==1|dm_categ==2))
egen dm`i'=max(dm`i'_), by(b01 y_id)
 }
g none=(dm1==0&dm2==0&dm3==0&dm4==0&dm5==0&dm6==0&dm7==0)

*** LABELS
****************************************************************
* Household characteristics
ta categ_hh, g(categ_hh_) 
lab var categ_hh_1 "Married in couple household with no other adults" 
lab var categ_hh_2 "Married in extended family household with wife's in-laws" 
lab var categ_hh_3 "Married in extended family household without wife's in-laws" 
lab var categ_hh_4 "Married in household with co-wives" 
lab var categ_hh_5 "Never married living with parent(s)" 
lab var categ_hh_6 "Widow/er, divorced, or separated"
lab var hh_parents "Lives with parents"
lab var hh_inlaws "Lives with in-laws"

* Individual characteristics
*g men=(female==0) 
lab var female "Female"
label define female 1"Women" 0"Men", replace
label values female female
label var y_age "Age"
label var mono_married "Monogamous union"
label var pol_married "Polygamous union"
label var wi_div_sep "Widow/er, divorced, separated"
label var never_married "Never married"
label var educ_illiterate "No schooling"
label var educ_primary   "At least some primary school but no secondary school"
label var educ_sec_tert "Some secondary school or higher"
label var educ_attending "Currently attending school"

* Decision-making variables
lab var share_effective_power "Share of all decisions not directly involved but have effective power"
lab var share_effective_power_water "Water decisions"
lab var share_effective_power_exp "Expenditure decisions"
lab var share_effective_power_ind "Personal individual decisions"

lab var share_dm "All decisions"
lab var share_dm_water "Water decisions"
lab var share_dm_exp "Expenditure decisions"
lab var share_dm_ind "Personal individual decisions"

lab var share_all "Share DM or eff power"
lab var share_ind "Share DM (IND)"
lab var share_all_ind "Share DM or eff power (IND)"
lab var share_water "Share DM (WATER)"
lab var share_all_water "Share DM or eff power (WATER)"
lab var share_exp "Share DM (EXP)"
lab var share_all_exp "Share DM or eff power (EXP)"

lab var dm1 "Directly involved in decision on water source for drinking"
lab var dm2 "Directly involved in decision on regular water expenditure"
lab var dm3 "Directly involved in decision on water allocation and use"
lab var dm4 "Directly involved in decision on large household purchases"
lab var dm5 "Directly involved in decision on health care for yourself"
lab var dm6 "Directly involved in decision on visit family or relative"
lab var dm7 "Directly involved in decision on use own money"

lab var all "Directly involved in all decisions made in the household"
lab var none "Not directly involved in all decisions made in the household"

save "$main\Data_exploring_DM.dta", replace

****************************************************************
*** FULL SAMPLE
****************************************************************
* Adults in the household
use "$main\Raw data\Household\household roster.dta", clear
keep if hh_age>=18 // Only adults
* Drop households with discrepancies in the relationships, ages, and/or gender:
dropvars // 138 observations deleted
drop if b01==3197 |  b01==7588 | b01==7516 | b01==1089 | b01==1099 | b01==3781 // 64 observations deleted
egen sex=max(hh_sex), by(b01 member_id)
egen age=max(hh_age), by(b01 member_id)
drop hh_sex hh_age
rename (sex age) (hh_sex hh_age)
* Drop duplicated cases
drop parent_key
duplicates drop // 1,506
duplicates tag b01 member_id, g(tag)
drop if b01==2307 & member_id==1 & hh_spouse==2
drop if b01==2418 & member_id==4 & hh_marital==6
drop if b01==3855 & member_id==1 & hh_spouse==2
drop if tag!=0 & hh_school==. // 4 dropped
drop if tag!=0 & b01==587 & member_id==1 & hh_education==2
drop if tag!=0 & b01==1122 & member_id==1 & hh_education==13
drop if tag!=0 & b01==1226 & member_id==1 & hh_education==0
drop if tag!=0 & b01==5602 & member_id==1 & hh_school==1
drop if tag!=0 & b01==6578 & member_id==1 & hh_education==8
drop if tag!=0 & b01==7143 & member_id==1 & hh_school==1
drop tag
rename hh_education ed_grade 
rename hh_marital y_status
rename hh_school ed_school
rename member_id y_id
rename hh_age y_age
merge 1:m b01 y_id using "$main\Raw data\Individual\individual level.dta", keepusing(a01 ed_grade y_status ed_school) update
drop if _m==2
drop _m

g mono_married=(y_status==1) if y_status!=.
g pol_married=(y_status==2) if y_status!=.
g never_married=(y_status==6) if y_status!=.
g wi_div_sep=(y_status==4|y_status==5) if y_status!=.

g educ_illiterate=(ed_grade==0|ed_grade==1) if ed_grade!=.
g educ_attending=(ed_school==1) if ed_school!=.
g educ_primary  =(ed_grade>=2  & ed_grade<=9) if ed_grade!=.
g educ_sec_tert=(ed_grade>=10 & ed_grade<=18) if ed_grade!=.

label var y_age "Age"
label var mono_married "Monogamous union"
label var pol_married "Polygamous union"
label var wi_div_sep "Widow/er, divorced, separated"
label var never_married "Never married"
label var educ_illiterate "No schooling"
label var educ_primary   "At least some primary school but no secondary school"
label var educ_sec_tert "Some secondary school or higher"
label var educ_attending "Currently attending school"

g Ganze=(a01==1)
g Kaloleni=(a01==2)
g Magarini=(a01==3)

merge m:1 b01 using "$main\Raw data\samplingweights_round2.dta", keepusing(sampling_weight) 
drop if _m==2 // 276 using only
drop _m
merge m:1 b01 using "$main\htype.dta", keepusing(household_type) // 232 cases only master
drop if _m==2 // 0
drop _m
g ht_single=(household_type==1|household_type==2) if household_type!=.
g ht_couple=(household_type==3) if household_type!=.
g ht_parent_adult=(household_type==4) if household_type!=.
g ht_extended=(household_type==5) if household_type!=.
g ht_cowives=(household_type==6) if household_type!=.

lab var ht_single "Single adult households"
lab var ht_couple "Lives in household with a couple and no other adults"
lab var ht_parent_adult "Lives in household with parent and adult child"
lab var ht_extended "Lives in extended family household"
lab var ht_cowives "Lives in a household with co-wives"

merge 1:1 b01 y_id using "$main\ind_rel.dta" // 4 cases only master
drop if _m==2 // 3
drop _m
g female=(hh_sex==2) if hh_sex!=.
label define female 1"Women" 0"Men", replace
label values female female
save "$main\Full_sample.dta", replace

****************************************************************
*** ERASE INTERMEDIATE DATASETS
****************************************************************
erase "$main\all_rel.dta"
erase "$main\htype.dta"
erase "$main\BA notinvolved.dta"
erase "$main\conflict.dta"
erase "$main\DM.dta"
erase "$main\HH_charac.dta"
erase "$main\hh_relation.dta"
erase "$main\ind_rel.dta"
erase "$main\indiv_charac.dta"
erase "$main\Involvement.dta"
erase "$main\Persuation.dta"
erase "$main\WS_USED.dta"

****************************************************************
*** THE END
****************************************************************